/**
 ****************************************************************************************
 *
 * @file bas_service.h
 *
 * @brief Battery service implementation
 *
 * Copyright (C) 2015-2020 Dialog Semiconductor.
 * This computer program includes Confidential, Proprietary Information
 * of Dialog Semiconductor. All Rights Reserved.
 *
 ****************************************************************************************
 */


#ifndef BAS_SERVICE_H_
#define BAS_SERVICE_H_

#include "commons.h"
#include "osal.h"

/*********************************************************************
 *
 *      External variables
 */

/* BLE battery service handle */
extern ble_service_t *bas;

/* Timer handle for battery read/update operations */
extern OS_TIMER bas_tim;

/*********************************************************************
 *
 *      APIs
 */

/*
 * \brief Update battery level
 *
 * \param[in]  sdt_charging  Flag to indicate whether or not the device is connected to a charger
 *
 * \note When not connected to charger and the battery level is beyond a specified level,
 *       the device is forced to enter the hibernation mode.
 */
void bas_update(bool sdt_charging);

/*
 * \brief Read battery level
 *
 * Read the battery level by invoking the GPADC block
 *
 * \return The voltage expressed in percentage e.g. 55%
 *
 */
uint8_t read_battery_level(void);

/*
 * \brief Timer callback function
 *
 * This is the callback function of the timer used to read and update the battery
 * level indication periodically.
 *
 * \param[in] timer   Timer handle (this is the default function prototype required by the OS)
 *
 */
void bas_tim_cb(OS_TIMER timer);

#endif /* BAS_SERVICE_H_ */
