/**
 ****************************************************************************************
 *
 * @file distance_sw_fsm.h
 *
 * @brief Social distance tag application
 *
 * Copyright (C) 2015-2020 Dialog Semiconductor.
 * This computer program includes Confidential, Proprietary Information
 * of Dialog Semiconductor. All Rights Reserved.
 *
 ****************************************************************************************
 */

#ifndef DISTANCE_SW_FSM_H_
#define DISTANCE_SW_FSM_H_

#include "osal.h"

/*********************************************************************
 *
 *      Typedefs
 */

/* Advertising data structure */
typedef struct {
        uint8_t         pad1[5];
        uint8_t         uuid[16];
        uint8_t         pad2[2];
        uint8_t         type;
        uint32_t        UID;
        uint8_t         ToF;
        uint8_t         Conn_to_me;
        uint8_t         reserved;
} sdt_adv_report;

/* Device info structure */
typedef __PACKED_STRUCT {
        uint32_t        DevUID;
        uint8_t         DevType;
        uint8_t         DevToF;
        uint8_t         Dev_conn_to_me;
} id_info;

/*  Log entry structure */
typedef __PACKED_STRUCT {
        uint8_t         start;
        uint8_t         DevType;
        uint32_t        DevUID;
        uint16_t        year;           /**< Year from 1900 to 2999 */
        uint8_t         month;          /**< Month from 1 to 12 */
        uint8_t         mday;           /**< Day of month from 1 to 28, 29, 30 or 31 (as a function of month and year) */
        uint8_t         hour;           /**< Hour from 0 to 23 in 24-hour mode, or from 1 to 12 in 12-hour mode */
        uint8_t         minute;         /**< Minutes after the hour, in the range 0 to 59 */
        uint8_t         sec;            /**< Seconds after the minute, in the range 0 to 59 */
        uint8_t         Zone;
        uint8_t         ContactDevType;
        uint32_t        ContactDevUID;
        uint8_t         BatPercent;
} log_entry;

/* Advertised data report structure */
typedef struct {
        void            *next;
        bd_address_t    bd_addr;
        int32_t         rssi_sum;
        uint16_t        num_of_scan_occurences;
        id_info         id;
} adv_dev_t;

typedef enum {
        ADV_SCAN_INTERVAL_FAST  = 0,
        ADV_SCAN_INTERVAL_POWER = 1,
} adv_setting_t;

/* Log retrieval error enumeration */
typedef enum {
        LOG_RET_OK = 0,
        LOG_RET_GENERIC_ERROR,
        LOG_RET_INVALID_ZONE,
} log_req_t;

/* Zone pointer action enumeration */
typedef enum {
        ZONE_PTR_RETAIN = 0,
        ZONE_PTR_RESET,
} zone_ptr_action_t;

/* Folder reset enumeration */
typedef enum {
        FOLDER_RETAIN = 0,
        FOLDER_RESET,
} folder_action_t;

#endif /* DISTANCE_SW_FSM_H_ */
