/**
 ****************************************************************************************
 *
 * @file pcb_hw_id.h
 *
 * @brief Custom mechanism for ID the PCB revision through the P0_28-P0_31
 *        P0_28 is the LSB
 *
 *                        +-------+-------+-------+-------+
 *        eg.             | P0_31 | P0_30 | P0_29 | P0_28 |
 *                        +-------+-------+-------+-------+
 *  pcb ver. 5 --> 0x5  = |   0   |   1   |   0   |   1   |
 *                        +-------+-------+-------+-------+
 *
 * Copyright (c) 2019 Dialog Semiconductor. All rights reserved.
 *
 * This software ("Software") is owned by Dialog Semiconductor. By using this Software
 * you agree that Dialog Semiconductor retains all intellectual property and proprietary
 * rights in and to this Software and any use, reproduction, disclosure or distribution
 * of the Software without express written permission or a license agreement from Dialog
 * Semiconductor is strictly prohibited. This Software is solely for use on or in
 * conjunction with Dialog Semiconductor products.
 *
 * EXCEPT AS OTHERWISE PROVIDED IN A LICENSE AGREEMENT BETWEEN THE PARTIES OR AS
 * REQUIRED BY LAW, THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. EXCEPT AS OTHERWISE PROVIDED
 * IN A LICENSE AGREEMENT BETWEEN THE PARTIES OR BY LAW, IN NO EVENT SHALL DIALOG
 * SEMICONDUCTOR BE LIABLE FOR ANY DIRECT, SPECIAL, INDIRECT, INCIDENTAL, OR
 * CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
 * PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE SOFTWARE.
 *
 ****************************************************************************************
 */

/*********************************************************************
 *
 *      External variables
 */

extern uint8_t pcb_version;       /* 0xFF is an invalid value. The SW should call the
                                   * get_pcb_version() to get the PCB HW */

/*********************************************************************
 *
 *      API
 */

/*
 * \brief Get PCB version
 *
 * Read the status of the GPIOs P0_28 to P0_31 to get the version of the PCB of the device.
 * This can be used in the future versions of the HW/SW to configure the correct pins for
 * each interface.
 */
void get_pcb_version(void);
