/**
 ****************************************************************************************
 *
 * @file time_service.c
 *
 * @brief BLE time service initialization
 *
 * Copyright (C) 2015-2020 Dialog Semiconductor.
 * This computer program includes Confidential, Proprietary Information
 * of Dialog Semiconductor. All Rights Reserved.
 *
 ****************************************************************************************
 */

/*
 * Current Time Service data
 */
#include <stdio.h>
#include <stdbool.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include "osal.h"
#include "sys_watchdog.h"
#include "ble_att.h"
#include "ble_common.h"
#include "ble_gap.h"
#include "ble_gatts.h"
#include "ble_service.h"
#include "ble_uuid.h"
#include "cts.h"
#include "commons.h"

/*********************************************************************
 *
 *      Static code
 */

/* Callback function to be called when a peer device requests the current time */
static void cts_get_time_cb(ble_service_t *svc, uint16_t conn_idx)
{
        cts_current_time_t time;

        hw_rtc_get_time_clndr(&time_cfg, &calendar_cfg);

        time.date_time.year     = calendar_cfg.year;
        time.date_time.month    = calendar_cfg.month;
        time.date_time.day      = calendar_cfg.mday;
        time.date_time.hours    = time_cfg.hour;
        time.date_time.minutes  = time_cfg.minute;
        time.date_time.seconds  = time_cfg.sec;
        time.day_of_week        = calendar_cfg.wday;
        time.adjust_reason      = CTS_AR_NO_CHANGE; //! Don't care

        cts_get_time_cfm(svc, conn_idx, ATT_ERROR_OK, &time);
}

/* Callback function to be called when a peer device declares a new current time */
static void cts_set_time_cb(ble_service_t *svc, uint16_t conn_idx, const cts_current_time_t *time)
{
        int status;

        if (!cts_is_current_time_valid(time)) {
                cts_set_time_cfm(svc, conn_idx, CTS_ERROR_DATA_FIELD_IGNORED);
                return;
        }

        calendar_cfg.year       = time->date_time.year;
        calendar_cfg.month      = time->date_time.month;
        calendar_cfg.mday       = time->date_time.day;
        time_cfg.hour           = time->date_time.hours;
        time_cfg.minute         = time->date_time.minutes;
        time_cfg.sec            = time->date_time.seconds;
        calendar_cfg.wday       = time->day_of_week;

        status = hw_rtc_set_time_clndr(&time_cfg, &calendar_cfg);

        if (status != HW_RTC_VALID_ENTRY) { //! Any invalid entry should cause a time update rejection
                cts_set_time_cfm(svc, conn_idx, CTS_ERROR_DATA_FIELD_IGNORED);
        }
        cts_set_time_cfm(svc, conn_idx, ATT_ERROR_OK);
}

/*********************************************************************
 *
 *      Non static code
 */

/* User-defined callback functions */
const cts_callbacks_t cts_callbacks = {
        .get_time = cts_get_time_cb,
        .set_time = cts_set_time_cb,
        .set_local_time_info = NULL,
        .get_ref_time_info   = NULL,
};
