/**
 ****************************************************************************************
 *
 * @file commons.h
 *
 * @brief Common parts
 *
 * Copyright (C) 2016-2020 Dialog Semiconductor.
 * This computer program includes Confidential, Proprietary Information
 * of Dialog Semiconductor. All Rights Reserved.
 *
 ****************************************************************************************
 */
#ifndef COMMONS_H_
#define COMMONS_H_

#include "hw_rtc.h"

/*
 * Notification bit-masks
 *
 * \warning  bit #0 is always assigned to BLE event queue notification
 *           bit #5 is always assigned to RFMON report notification
 */
#define BLE_START_SCAN_NOTIF             ( 1 << 1 )
#define PROX_CHECK_APP_NOTIFY            ( 1 << 2 )
#define RANGE_APP_NOTIFY                 ( 1 << 3 )
#define PERFORM_RANGING_NOTIFY           ( 1 << 4 )
#define DTE_TO_NOTIF                     ( 1 << 5 )
#define DANGER_ALERT_NOTIFY              ( 1 << 6 )
#define WARNING_ALERT_NOTIFY             ( 1 << 7 )
#define BAS_TMO_NOTIF                    ( 1 << 8 )

#define SDT_RANGING_TASK_PRIORITY        ( OS_TASK_PRIORITY_NORMAL + 1 )

/*
 * \brief RTC timer default values (on Power-On Reset)
 */
#define RTC_TIME_SECOND                 0
#define RTC_TIME_MINUTE                 5
#define RTC_TIME_HOUR                  18

/**
 * \brief RTC calendar default values (on Power-On Reset)
 */
#define RTC_CALENDAR_MONTH               4
#define RTC_CALENDAR_MONTH_DAY           7
#define RTC_CALENDAR_WEEK_DAY            1
#define RTC_CALENDAR_YEAR             2020

/* Distance zones enumeration */
typedef enum {
        DANGER_ZONE      = 0x0,
        WARNING_ZONE,
        COARSE_ZONE,
        BLE_LIMIT_ZONE,
} LOG_DISTANCE_ZONE;

extern rtc_time time_cfg;
extern rtc_calendar calendar_cfg;

#endif /* COMMONS_H_ */
