/**
 * \addtogroup MID_SYS_ADAPTERS
 * \{
 * \addtogroup ADAPTER_CONFIGURATION
 * \{
 */

/**
 ****************************************************************************************
 *
 * @file platform_nvparam.h
 *
 * @brief Configuration of non-volatile parameters on platform
 *
 * Copyright (C) 2016-2019 Dialog Semiconductor.
 * This computer program includes Confidential, Proprietary Information
 * of Dialog Semiconductor. All Rights Reserved.
 *
 ****************************************************************************************
 */

#ifndef PLATFORM_NVPARAM_H_
#define PLATFORM_NVPARAM_H_

#include "ad_nvparam_defs.h"

/**
 * Tags definition for 'ble_platform' area.
 *
 * \note These are the same as tags for RW NVDS to make translation easier.
 */
#define NVPARAM_BLE_PLATFORM_BD_ADDRESS             0x01 // 6 bytes array
#define NVPARAM_BLE_PLATFORM_LPCLK_DRIFT            0x07 // 16bit value
#define NVPARAM_BLE_PLATFORM_SLEEP_ENABLE           0x11 // byte
#define NVPARAM_BLE_PLATFORM_BLE_CA_TIMER_DUR       0x40 // 16bit value
#define NVPARAM_BLE_PLATFORM_BLE_CRA_TIMER_DUR      0x41 // byte
#define NVPARAM_BLE_PLATFORM_BLE_CA_MIN_RSSI        0x42 // byte
#define NVPARAM_BLE_PLATFORM_BLE_CA_NB_PKT          0x43 // 16bit value
#define NVPARAM_BLE_PLATFORM_BLE_CA_NB_BAD_PKT      0x44 // 16bit value
#define NVPARAM_BLE_PLATFORM_IRK                    0x80 // 16 bytes array

/**
 * Offset definition for 'ble_platform' area.
 */
#define NVPARAM_OFFSET_BLE_PLATFORM_BD_ADDRESS              0x0000
#define NVPARAM_OFFSET_BLE_PLATFORM_LPCLK_DRIFT             0x0007
#define NVPARAM_OFFSET_BLE_PLATFORM_SLEEP_ENABLE            0x0013
#define NVPARAM_OFFSET_BLE_PLATFORM_BLE_CA_TIMER_DUR        0x0017
#define NVPARAM_OFFSET_BLE_PLATFORM_BLE_CRA_TIMER_DUR       0x001A
#define NVPARAM_OFFSET_BLE_PLATFORM_BLE_CA_MIN_RSSI         0x001C
#define NVPARAM_OFFSET_BLE_PLATFORM_BLE_CA_NB_PKT           0x001E
#define NVPARAM_OFFSET_BLE_PLATFORM_BLE_CA_NB_BAD_PKT       0x0021
#define NVPARAM_OFFSET_BLE_PLATFORM_IRK                     0x0024
/**
 * 'ble_platform' area definition
 *
 * Each parameter value includes additional byte for validity data, i.e. 1st byte of value shall be
 * set to 0x00 for parameter value to be considered valid.
 */
NVPARAM_AREA(ble_platform, NVMS_PARAM_PART, 0x0000)
        NVPARAM_PARAM(NVPARAM_BLE_PLATFORM_BD_ADDRESS,              NVPARAM_OFFSET_BLE_PLATFORM_BD_ADDRESS, 7)          // uint8[6]
        NVPARAM_PARAM(NVPARAM_BLE_PLATFORM_LPCLK_DRIFT,             NVPARAM_OFFSET_BLE_PLATFORM_LPCLK_DRIFT, 3)         // uint16
        NVPARAM_PARAM(NVPARAM_BLE_PLATFORM_SLEEP_ENABLE,            NVPARAM_OFFSET_BLE_PLATFORM_SLEEP_ENABLE, 2)        // uint8
        NVPARAM_PARAM(NVPARAM_BLE_PLATFORM_BLE_CA_TIMER_DUR,        NVPARAM_OFFSET_BLE_PLATFORM_BLE_CA_TIMER_DUR, 3)    // uint16
        NVPARAM_PARAM(NVPARAM_BLE_PLATFORM_BLE_CRA_TIMER_DUR,       NVPARAM_OFFSET_BLE_PLATFORM_BLE_CRA_TIMER_DUR, 2)   // uint8
        NVPARAM_PARAM(NVPARAM_BLE_PLATFORM_BLE_CA_MIN_RSSI,         NVPARAM_OFFSET_BLE_PLATFORM_BLE_CA_MIN_RSSI, 2)     // uint8
        NVPARAM_PARAM(NVPARAM_BLE_PLATFORM_BLE_CA_NB_PKT,           NVPARAM_OFFSET_BLE_PLATFORM_BLE_CA_NB_PKT, 3)       // uint16
        NVPARAM_PARAM(NVPARAM_BLE_PLATFORM_BLE_CA_NB_BAD_PKT,       NVPARAM_OFFSET_BLE_PLATFORM_BLE_CA_NB_BAD_PKT, 3)   // uint16
        NVPARAM_PARAM(NVPARAM_BLE_PLATFORM_IRK,                     NVPARAM_OFFSET_BLE_PLATFORM_IRK, 17)                // uint8[16]
NVPARAM_AREA_END()


/* tags for the sdt_platform area */
#define NVPARAM_SDT_PLATFORM_UID                                0x10 // 4 bytes (ULONG)
#define NVPARAM_SDT_PLATFORM_TYPE                               0x11 // 1 byte  (UINT8)
#define NVPARAM_SDT_PLATFORM_TOF                                0x12 // 1 byte  (UINT8)
#define NVPARAM_SDT_PLATFORM_CONNECT_TO_ME                      0x13 // 1 byte  (UINT8)

#define NVPARAM_SDT_PLATFORM_FIRST_BOOT                         0x20 // 1 byte (0xFF --> First boot)

#define NVPARAM_SDT_PLATFORM_DANGER_RSSI                        0x30 // 1 byte (INT8) value
#define NVPARAM_SDT_PLATFORM_WARNING_RSSI                       0x31 // 1 byte (INT8) value
#define NVPARAM_SDT_PLATFORM_COARSE_RSSI                        0x32 // 1 byte (INT8) value

#define NVPARAM_SDT_PLATFORM_DANGER_DISTANCE                    0x40 // in centimeters, 2 bytes (UINT16) value
#define NVPARAM_SDT_PLATFORM_WARNING_DISTANCE                   0x41 // in centimeters, 2 bytes (UINT16) value
#define NVPARAM_SDT_PLATFORM_COARSE_DISTANCE                    0x42 // in centimeters, 2 bytes (UINT16) value

#define NVPARAM_SDT_PLATFORM_ADV_UUID                           0x50 // 16-bytes UUID 128bit
#define NVPARAM_SDT_PLATFORM_ADV_NAME                           0x51 // 29-bytes Adv Device Name

#define NVPARAM_SDT_PLATFORM_PROX_DUR_MS                        0x60 // 4-bytes Scanning timeout in ms to determine that a device is close for that time

/* tags offsets */
#define NVPARAM_OFFSET_SDT_PLATFORM_UID                          0 // 4 bytes (ULONG)

#define NVPARAM_OFFSET_SDT_PLATFORM_TYPE                         4 // 1 byte  (UINT8)
#define NVPARAM_OFFSET_SDT_PLATFORM_TOF                          5 // 1 byte  (UINT8)
#define NVPARAM_OFFSET_SDT_PLATFORM_CONNECT_TO_ME                6 // 1 byte  (UINT8)

#define NVPARAM_OFFSET_SDT_PLATFORM_FIRST_BOOT                   7 // 1 byte (0xFF --> First boot)

#define NVPARAM_OFFSET_SDT_PLATFORM_DANGER_RSSI                  8 // 1 byte (INT8)
#define NVPARAM_OFFSET_SDT_PLATFORM_WARNING_RSSI                 9 // 1 byte (INT8)
#define NVPARAM_OFFSET_SDT_PLATFORM_COARSE_RSSI                 10 // 1 byte (INT8)

#define NVPARAM_OFFSET_SDT_PLATFORM_DANGER_DISTANCE             12 // 2 bytes (UINT16)
#define NVPARAM_OFFSET_SDT_PLATFORM_WARNING_DISTANCE            16 // 2 bytes (UINT16)
#define NVPARAM_OFFSET_SDT_PLATFORM_COARSE_DISTANCE             20 // 2 bytes (UINT16)

#define NVPARAM_OFFSET_SDT_PLATFORM_ADV_UUID                    24 // 16-bytes UUID 128bit
#define NVPARAM_OFFSET_SDT_PLATFORM_ADV_NAME                    40 // 29-bytes Adv Device Name

#define NVPARAM_OFFSET_SDT_PLATFORM_PROX_DUR_MS                 70 // 4-bytes Scanning timeout in ms to determine that a device is close for that time

/**
 * 'sdt_platform' area definition */
NVPARAM_AREA(sdt_platform, NVMS_PARAM_PART, 0x0100) /* 0x100 is the start of the next page in FLASH */
NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_UID,                 NVPARAM_OFFSET_SDT_PLATFORM_UID,              4)

NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_TYPE,                NVPARAM_OFFSET_SDT_PLATFORM_TYPE,             1)
NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_TOF,                 NVPARAM_OFFSET_SDT_PLATFORM_TOF,              1)
NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_CONNECT_TO_ME,       NVPARAM_OFFSET_SDT_PLATFORM_CONNECT_TO_ME,    1)
NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_FIRST_BOOT,          NVPARAM_OFFSET_SDT_PLATFORM_FIRST_BOOT,       1)
NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_DANGER_RSSI,         NVPARAM_OFFSET_SDT_PLATFORM_DANGER_RSSI,      1)
NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_WARNING_RSSI,        NVPARAM_OFFSET_SDT_PLATFORM_WARNING_RSSI,     1)
NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_COARSE_RSSI,         NVPARAM_OFFSET_SDT_PLATFORM_COARSE_RSSI,      1)

NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_DANGER_DISTANCE,     NVPARAM_OFFSET_SDT_PLATFORM_DANGER_DISTANCE,  2)
NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_WARNING_DISTANCE,    NVPARAM_OFFSET_SDT_PLATFORM_WARNING_DISTANCE, 2)
NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_COARSE_DISTANCE,     NVPARAM_OFFSET_SDT_PLATFORM_COARSE_DISTANCE,  2)

NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_ADV_UUID,            NVPARAM_OFFSET_SDT_PLATFORM_ADV_UUID,         16)
NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_ADV_NAME,            NVPARAM_OFFSET_SDT_PLATFORM_ADV_NAME,         29) // (SCAN_RSP_DATA_LEN - 2)

NVPARAM_PARAM(NVPARAM_SDT_PLATFORM_PROX_DUR_MS,         NVPARAM_OFFSET_SDT_PLATFORM_PROX_DUR_MS,      4)

NVPARAM_AREA_END()

#endif /* PLATFORM_NVPARAM_H_ */

/**
 * \}
 * \}
 */
