/**
 ****************************************************************************************
 *
 * @file sdt_application_defaults.h
 *
 * @brief SDT application default macro configurations
 *
 * Copyright (C) 2015-2020 Dialog Semiconductor.
 * This computer program includes Confidential, Proprietary Information
 * of Dialog Semiconductor. All Rights Reserved.
 *
 ****************************************************************************************
 */

#ifndef SDT_APPLICATION_DEFAULTS_H_
#define SDT_APPLICATION_DEFAULTS_H_

/*
 * Macro to enable logging in the flash memory used.
 *
 * \warning It's essential that a file system is used.
 */
#ifndef SDT_LOGGING_ENABLE
        #define SDT_LOGGING_ENABLE            ( 1 )
        /* Declare logging dependencies */
        #undef dg_config_USE_FATFS
        #define dg_config_USE_FATFS           ( 1 )
#endif

#ifndef SDT_BATTERY_MONITORING_ENABLE
#define SDT_BATTERY_MONITORING_ENABLE         ( 1 )
#endif

/*
 * Macro to enable TOF operations used to perform
 * ranging calculations.
 */
#ifndef SDT_TOF_RANGING_ENABLE
        #define SDT_TOF_RANGING_ENABLE        ( 1 )
        /* Declare TOF dependencies */
        #undef dg_configENABLE_DTE
        #define dg_configENABLE_DTE           ( 1 )
        #undef dg_cfgENABLE_TOF
        #define dg_cfgENABLE_TOF              ( 1 )
        #undef dg_cfgENABLE_IQ_SAMPLING
        #define dg_cfgENABLE_IQ_SAMPLING      ( 1 )
#endif

#ifndef RFMON_NUM_OF_BUFFERS
#define RFMON_NUM_OF_BUFFERS                  ( 1 )
#endif

#ifndef RFMON_PACKET_BUFFER_SIZE
#define RFMON_PACKET_BUFFER_SIZE              ( 48 )
#endif

#ifndef RFMON_IQ_DATA_BUFFER_SIZE
#define RFMON_IQ_DATA_BUFFER_SIZE             ( 24 * 1024 )
#endif

#if ((SDT_LOGGING_ENABLE == 1) && (dg_config_USE_FATFS == 0))
#pragma message "Logging operations require a file system"
#endif

#if ((SDT_TOF_RANGING_ENABLE == 1) && ((dg_configENABLE_DTE == 0) ||  \
                        (dg_cfgENABLE_TOF == 0) ||                    \
                        (dg_cfgENABLE_IQ_SAMPLING == 0)))
#pragma message "Missing macro configurations for performing TOF operations"
#endif

#endif /* SDT_APPLICATION_DEFAULTS_H_ */
