/**
 ****************************************************************************************
 *
 * @file dte_common.h
 *
 * @brief DTE common code for central and peripheral role
 *
 * Copyright (C) 2018-2020 Dialog Semiconductor.
 * This computer program includes Confidential, Proprietary Information
 * of Dialog Semiconductor. All Rights Reserved.
 *
 ****************************************************************************************
 */

#ifndef DTE_COMMON_H_
#define DTE_COMMON_H_

#include "rfmon.h"
#include "ble_range_dte_config.h"
#include "osal.h"
#include "ble_gap.h"
#include "ble_service.h"

extern sampling_buffer_t *report_smpl_buf;

#define DTE_N_ATOM_MAX          (40)        /* max number of atoms */

#define DTE_ATOM_RX_LENGTH_US   (16)       /* length of meaningful data inside rfmon_sample_buffer */

/* default frequency stepping */
#define DTE_FREQ_STEP_MHZ       (2)
#define DTE_FREQ_START_MHZ      (2402)

#define AGC_FREEZE_LEVEL        (7)         /* manual AGC freeze level, from 0 ... 9 */

#define US_TO_SAMPLES(US_VAL)   (8 * US_VAL)                    /* 1msec equals 8000 samples */
#define US_TO_BYTES(US_VAL)     (US_TO_SAMPLES(US_VAL) * 4)     /* one sample consists of four bytes */


#define DTE_DATA_I_RESULT_WRITE         (0x14)
#define DTE_DATA_R_RESULT_NOTIFY        (0x17)
#define DTE_DATA_R_RESULT_NOTIFY_ENABLE (0x19)


typedef enum {
        DTE_ROLE_UNDEFINED = 0,
        DTE_ROLE_INITIATOR = 1,
        DTE_ROLE_RESPONDER = 2
} dte_role_t;

/* Structure for DTE data (results) */
typedef struct __attribute__((packed)) {
        uint16_t  event_counter;
        uint8_t   AGC_gain;
        int8_t    ble_rssi;
        int16_t   f_offset;
        uint8_t   invalid_atoms;
        uint8_t   reserved;     // for phase and amplitude word alignment
        float     phase[DTE_N_ATOM_MAX];
        uint16_t  amplitude[DTE_N_ATOM_MAX];
} dte_result_t;

typedef struct {
        dte_role_t role;
        int16_t    cw_offset;
        uint16     xtal32m_trim_value;
        uint8_t    flag_auto_xtal32_trim:1;
} config_params_t;

typedef enum {
        DTE_STATUS_STOP,
        DTE_STATUS_START,
        DTE_STATUS_CALC,
} dte_status_t;

typedef enum {
        DTE_NO_ERROR,
        DTE_ERROR_INSTANT_PASSED,
        DTE_ERROR_SYNC_FAILED,
        DTE_ERROR_RESULTS_TO,
        DTE_ERROR_DISCONNECTED,
        DTE_ERROR_LAST,
} dte_error_t;

typedef enum {
        DISABLED = 0,
        ENABLED,
        UNSUPPORTED,
} dte_caps_t;

typedef struct peripheral_context {
        dte_status_t dte_status;
        dte_error_t dte_err_code;

        float           dist_sum;
        float           dist_history[DIST_MA_WINDOW];
        uint8_t         widx;
} peripheral_context_t;

/* API needed so that main app can be notified and access the rfmon report buffer */
void init_rfmon_report(OS_TASK handle);
sampling_buffer_t *get_rfmon_report();

/* rfmon report event handler */
void handle_evt_gap_rfmon_report(ble_evt_gap_rfmon_report_t *report);

void calc_phases(sampling_buffer_t *smpl_buf, dte_result_t *result);

float calc_distance(dte_result_t *i_result, dte_result_t *r_result, uint8_t *dqf);

#endif /* DTE_COMMON_H_*/
