/**
 ****************************************************************************************
 *
 * @file dte_common.c
 *
 * @brief DTE common code for central and peripheral role
 *
 * Copyright (C) 2018-2020 Dialog Semiconductor.
 * This computer program includes Confidential, Proprietary Information
 * of Dialog Semiconductor. All Rights Reserved.
 *
 ****************************************************************************************
 */

#include <stdio.h>
#include "osal.h"
#include "sys_trng.h"
#include "sys_clock_mgr.h"
#include "ad_nvms.h"
#include "ble_gap.h"

#include "dte_common.h"

#if ENABLE_CW_DIST_CALC
#include "iq_demultiplex.h"
#include "cw_distance.h"
#endif

#include "sdk_list.h"

__RETAINED sampling_buffer_t *report_smpl_buf;

__RETAINED_CODE sampling_buffer_t *get_rfmon_report()
{
        return report_smpl_buf;
}

void calc_phases(sampling_buffer_t *smpl_buf, dte_result_t *result)
{
        uint32_t *sampling_start = (uint32_t *) smpl_buf->header.sampling_start;
        uint32_t sampling_len = smpl_buf->header.sampling_end - smpl_buf->header.sampling_start;

        /* get agc gain from acquisition results */
        result->AGC_gain = smpl_buf->header.agc_value;

        /* get ble connection rssi from acquisition results */
        result->ble_rssi = smpl_buf->header.rssi;

        if (smpl_buf->header.oflow) {
//                OS_ASSERT(0);
                return;
        }

#if ENABLE_CW_DIST_CALC

        cm_sys_clk_set(sysclk_PLL96);

        /* buffer address is not fixed, depends on rfmon report buffer */
        iq_demux_init(sampling_start, sampling_len/4);
        bool valid_sample = cwd_set_buffer(sampling_start, sampling_len/4);
        if (valid_sample == false) {
//                OS_ASSERT(valid_sample);
                return;
        }

        iq_demultiplex();

#if ENABLE_IFFT_DIST_CALC
        result->f_offset = roundf(cwd_calc_phase_mag_data(result->phase, result->amplitude, &result->invalid_atoms));
#else
        result->f_offset = roundf(cwd_calc_phase_data(result->phase, &result->invalid_atoms));
#endif /* ENABLE_IFFT_DIST_CALC */

        cm_sys_clk_set(sysclk_XTAL32M);

#endif /* ENABLE_CW_DIST_CALC*/
}


float calc_distance(dte_result_t *i_result, dte_result_t *r_result, uint8_t *dqf)
{
        float distance = 0;

#if ENABLE_CW_DIST_CALC

        cm_sys_clk_set(sysclk_PLL96);

#if ENABLE_IFFT_DIST_CALC
        distance = cwd_calc_ifft_distance_phase_mag(i_result->phase, i_result->amplitude,
                                                                r_result->phase, r_result->amplitude);
#else
        distance = cwd_calc_distance(i_result->phase, r_result->phase);
#endif /* ENABLE_IFFT_DIST_CALC */

        /* Invalidate measurement in case of unreal distance values */
        *dqf = (distance == INFINITY) ? 0 : cwd_calc_dqf(i_result->f_offset, r_result->f_offset, i_result->invalid_atoms, r_result->invalid_atoms);

        cm_sys_clk_set(sysclk_XTAL32M);

#endif /* ENABLE_CW_DIST_CALC */

        return distance;
}
